Class: Smith::Models::Normalizer::Decision
- Inherits:
-
Data
- Object
- Data
- Smith::Models::Normalizer::Decision
- Defined in:
- lib/smith/models/normalizer.rb
Overview
Decision record emitted as a :normalizer_decision trace event. The Decision.kind value space is exhaustively documented in the plan; adding a new kind requires updating the trace CONFIG_MAP.
Instance Attribute Summary collapse
-
#detail ⇒ Object
readonly
Returns the value of attribute detail.
-
#kind ⇒ Object
readonly
Returns the value of attribute kind.
-
#model_id ⇒ Object
readonly
Returns the value of attribute model_id.
Instance Attribute Details
#detail ⇒ Object (readonly)
Returns the value of attribute detail
28 29 30 |
# File 'lib/smith/models/normalizer.rb', line 28 def detail @detail end |
#kind ⇒ Object (readonly)
Returns the value of attribute kind
28 29 30 |
# File 'lib/smith/models/normalizer.rb', line 28 def kind @kind end |
#model_id ⇒ Object (readonly)
Returns the value of attribute model_id
28 29 30 |
# File 'lib/smith/models/normalizer.rb', line 28 def model_id @model_id end |